summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvas_imp.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 16:20:48 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 16:20:48 -0600
commite63beeb5bdb82987b1e00bc35178667786fbad48 (patch)
treeab77b6ac830b7944d5d1eb9ce8f81feb8fdab948 /kjsembed/qtbindings/qcanvas_imp.cpp
parent67557a2b56c0678c22ab1b00c4fd0224c5e9ed99 (diff)
downloadtdebindings-e63beeb5bdb82987b1e00bc35178667786fbad48.tar.gz
tdebindings-e63beeb5bdb82987b1e00bc35178667786fbad48.zip
Fix incorrect conversion
Diffstat (limited to 'kjsembed/qtbindings/qcanvas_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvas_imp.cpp140
1 files changed, 70 insertions, 70 deletions
diff --git a/kjsembed/qtbindings/qcanvas_imp.cpp b/kjsembed/qtbindings/qcanvas_imp.cpp
index d686d862..22e8c40b 100644
--- a/kjsembed/qtbindings/qcanvas_imp.cpp
+++ b/kjsembed/qtbindings/qcanvas_imp.cpp
@@ -23,12 +23,12 @@
*/
namespace KJSEmbed {
-TTQCanvasImp::TQCanvasImp( KJS::ExecState *exec, int mid, bool constructor )
+TQCanvasImp::TQCanvasImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-TTQCanvasImp::~TQCanvasImp()
+TQCanvasImp::~TQCanvasImp()
{
}
@@ -43,7 +43,7 @@ void TQCanvasImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -116,7 +116,7 @@ void TQCanvasImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -129,25 +129,25 @@ void TQCanvasImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TTQCanvas pointer from an Object.
+ * Extract a TQCanvas pointer from an Object.
*/
-TTQCanvas *TQCanvasImp::toTQCanvas( KJS::Object &self )
+TQCanvas *TQCanvasImp::toTQCanvas( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TTQObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TTQCanvas *>( obj );
+ return dynamic_cast<TQCanvas *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TTQCanvas" )
+ if ( op->typeName() != "TQCanvas" )
return 0;
- return op->toNative<TTQCanvas>();
+ return op->toNative<TQCanvas>();
}
/**
@@ -173,7 +173,7 @@ KJS::Object TQCanvasImp::construct( KJS::ExecState *exec, const KJS::List &args
break;
}
- TTQString msg = i18n("TQCanvasCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("TQCanvasCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -181,21 +181,21 @@ KJS::Object TQCanvasImp::construct( KJS::ExecState *exec, const KJS::List &args
KJS::Object TQCanvasImp::TQCanvas_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter TTQObject *
+ // Unsupported parameter TQObject *
- TTQObject * arg0 = extractTQObject(exec,args,0);
+ TQObject * arg0 = extractTQObject(exec,args,0);
const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
- // We should now create an instance of the TTQCanvas object
+ // We should now create an instance of the TQCanvas object
- TTQCanvas *ret = new TTQCanvas(
+ TQCanvas *ret = new TQCanvas(
arg0,
arg1 );
- JSOpaqueProxy *prx = new JSOpaqueProxy( ret, "TTQCanvas");
+ JSOpaqueProxy *prx = new JSOpaqueProxy( ret, "TQCanvas");
return KJS::Object( prx );
}
@@ -207,13 +207,13 @@ KJS::Object TQCanvasImp::TQCanvas_2( KJS::ExecState *exec, const KJS::List &args
int arg1 = extractInt(exec, args, 1);
- // We should now create an instance of the TTQCanvas object
+ // We should now create an instance of the TQCanvas object
- TTQCanvas *ret = new TTQCanvas(
+ TQCanvas *ret = new TQCanvas(
arg0,
arg1 );
- JSOpaqueProxy *prx = new JSOpaqueProxy( ret, "TTQCanvas");
+ JSOpaqueProxy *prx = new JSOpaqueProxy( ret, "TQCanvas");
return KJS::Object( prx );
}
@@ -223,7 +223,7 @@ KJS::Object TQCanvasImp::TQCanvas_3( KJS::ExecState *exec, const KJS::List &args
// Unsupported parameter TQPixmap
- TTQPixmap arg0 = extractTQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractTQPixmap(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -234,9 +234,9 @@ KJS::Object TQCanvasImp::TQCanvas_3( KJS::ExecState *exec, const KJS::List &args
int arg4 = extractInt(exec, args, 4);
- // We should now create an instance of the TTQCanvas object
+ // We should now create an instance of the TQCanvas object
- TTQCanvas *ret = new TTQCanvas(
+ TQCanvas *ret = new TQCanvas(
arg0,
arg1,
@@ -244,7 +244,7 @@ KJS::Object TQCanvasImp::TQCanvas_3( KJS::ExecState *exec, const KJS::List &args
arg3,
arg4 );
- JSOpaqueProxy *prx = new JSOpaqueProxy( ret, "TTQCanvas");
+ JSOpaqueProxy *prx = new JSOpaqueProxy( ret, "TQCanvas");
return KJS::Object( prx );
}
@@ -450,7 +450,7 @@ KJS::Value TQCanvasImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS
break;
}
- TTQString msg = i18n( "TQCanvasImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "TQCanvasImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -461,7 +461,7 @@ KJS::Value TQCanvasImp::setTiles_5( KJS::ExecState *exec, KJS::Object &obj, cons
// Unsupported parameter TQPixmap
return KJS::Value();
- TTQPixmap arg0; // Dummy
+ TQPixmap arg0; // Dummy
int arg1 = extractInt(exec, args, 1);
@@ -484,7 +484,7 @@ KJS::Value TQCanvasImp::setTiles_5( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value TQCanvasImp::setBackgroundPixmap_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPixmap arg0 = extractTQPixmap(exec, args, 0);
+ TQPixmap arg0 = extractTQPixmap(exec, args, 0);
instance->setBackgroundPixmap(
arg0 );
@@ -494,7 +494,7 @@ KJS::Value TQCanvasImp::setBackgroundPixmap_6( KJS::ExecState *exec, KJS::Object
KJS::Value TQCanvasImp::backgroundPixmap_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPixmap ret;
+ TQPixmap ret;
ret = instance->backgroundPixmap( );
return convertToValue( exec, ret );
@@ -504,7 +504,7 @@ KJS::Value TQCanvasImp::backgroundPixmap_7( KJS::ExecState *exec, KJS::Object &o
KJS::Value TQCanvasImp::setBackgroundColor_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQColor arg0 = extractTQColor(exec, args, 0);
+ TQColor arg0 = extractTQColor(exec, args, 0);
instance->setBackgroundColor(
arg0 );
@@ -622,7 +622,7 @@ KJS::Value TQCanvasImp::height_18( KJS::ExecState *exec, KJS::Object &obj, const
KJS::Value TQCanvasImp::size_19( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQSize ret;
+ TQSize ret;
ret = instance->size( );
return convertToValue( exec, ret );
@@ -631,7 +631,7 @@ KJS::Value TQCanvasImp::size_19( KJS::ExecState *exec, KJS::Object &obj, const K
KJS::Value TQCanvasImp::rect_20( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect ret;
+ TQRect ret;
ret = instance->rect( );
return convertToValue( exec, ret );
@@ -656,7 +656,7 @@ KJS::Value TQCanvasImp::onCanvas_21( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQCanvasImp::onCanvas_22( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPoint arg0 = extractTQPoint(exec, args, 0);
+ TQPoint arg0 = extractTQPoint(exec, args, 0);
bool ret;
ret = instance->onCanvas(
@@ -683,7 +683,7 @@ KJS::Value TQCanvasImp::validChunk_23( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasImp::validChunk_24( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPoint arg0 = extractTQPoint(exec, args, 0);
+ TQPoint arg0 = extractTQPoint(exec, args, 0);
bool ret;
ret = instance->validChunk(
@@ -775,7 +775,7 @@ KJS::Value TQCanvasImp::setAllChanged_30( KJS::ExecState *exec, KJS::Object &obj
KJS::Value TQCanvasImp::setChanged_31( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect arg0 = extractTQRect(exec, args, 0);
+ TQRect arg0 = extractTQRect(exec, args, 0);
instance->setChanged(
arg0 );
@@ -786,7 +786,7 @@ KJS::Value TQCanvasImp::setChanged_31( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasImp::setUnchanged_32( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect arg0 = extractTQRect(exec, args, 0);
+ TQRect arg0 = extractTQRect(exec, args, 0);
instance->setUnchanged(
arg0 );
@@ -797,10 +797,10 @@ KJS::Value TQCanvasImp::setUnchanged_32( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasImp::addItemToChunk_33( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasItem *
return KJS::Value();
- TTQCanvasItem * arg0; // Dummy
+ TQCanvasItem * arg0; // Dummy
int arg1 = extractInt(exec, args, 1);
@@ -817,10 +817,10 @@ KJS::Value TQCanvasImp::addItemToChunk_33( KJS::ExecState *exec, KJS::Object &ob
KJS::Value TQCanvasImp::removeItemFromChunk_34( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasItem *
return KJS::Value();
- TTQCanvasItem * arg0; // Dummy
+ TQCanvasItem * arg0; // Dummy
int arg1 = extractInt(exec, args, 1);
@@ -837,10 +837,10 @@ KJS::Value TQCanvasImp::removeItemFromChunk_34( KJS::ExecState *exec, KJS::Objec
KJS::Value TQCanvasImp::addItemToChunkContaining_35( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasItem *
return KJS::Value();
- TTQCanvasItem * arg0; // Dummy
+ TQCanvasItem * arg0; // Dummy
int arg1 = extractInt(exec, args, 1);
@@ -857,10 +857,10 @@ KJS::Value TQCanvasImp::addItemToChunkContaining_35( KJS::ExecState *exec, KJS::
KJS::Value TQCanvasImp::removeItemFromChunkContaining_36( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasItem *
return KJS::Value();
- TTQCanvasItem * arg0; // Dummy
+ TQCanvasItem * arg0; // Dummy
int arg1 = extractInt(exec, args, 1);
@@ -885,7 +885,7 @@ KJS::Value TQCanvasImp::allItems_37( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQCanvasImp::collisions_38( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPoint arg0 = extractTQPoint(exec, args, 0);
+ TQPoint arg0 = extractTQPoint(exec, args, 0);
instance->collisions(
arg0 );
@@ -896,7 +896,7 @@ KJS::Value TQCanvasImp::collisions_38( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasImp::collisions_39( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect arg0 = extractTQRect(exec, args, 0);
+ TQRect arg0 = extractTQRect(exec, args, 0);
instance->collisions(
arg0 );
@@ -907,12 +907,12 @@ KJS::Value TQCanvasImp::collisions_39( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasImp::collisions_40( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQPointArray arg0; // TODO (hack for qcanvas)
+ TQPointArray arg0; // TODO (hack for qcanvas)
- // Unsupported parameter const TTQCanvasItem *
+ // Unsupported parameter const TQCanvasItem *
return KJS::Value();
- const TTQCanvasItem * arg1; // Dummy
+ const TQCanvasItem * arg1; // Dummy
bool arg2 = extractBool(exec, args, 2);
@@ -927,12 +927,12 @@ KJS::Value TQCanvasImp::collisions_40( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasImp::drawArea_41( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect arg0 = extractTQRect(exec, args, 0);
+ TQRect arg0 = extractTQRect(exec, args, 0);
- // Unsupported parameter TTQPainter *
+ // Unsupported parameter TQPainter *
return KJS::Value();
- TTQPainter * arg1; // Dummy
+ TQPainter * arg1; // Dummy
bool arg2 = extractBool(exec, args, 2);
@@ -947,10 +947,10 @@ KJS::Value TQCanvasImp::drawArea_41( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQCanvasImp::addView_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasView *
return KJS::Value();
- TTQCanvasView * arg0; // Dummy
+ TQCanvasView * arg0; // Dummy
instance->addView(
arg0 );
@@ -961,10 +961,10 @@ KJS::Value TQCanvasImp::addView_42( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value TQCanvasImp::removeView_43( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasView *
return KJS::Value();
- TTQCanvasView * arg0; // Dummy
+ TQCanvasView * arg0; // Dummy
instance->removeView(
arg0 );
@@ -975,12 +975,12 @@ KJS::Value TQCanvasImp::removeView_43( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasImp::drawCanvasArea_44( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect arg0 = extractTQRect(exec, args, 0);
+ TQRect arg0 = extractTQRect(exec, args, 0);
- // Unsupported parameter TTQPainter *
+ // Unsupported parameter TQPainter *
return KJS::Value();
- TTQPainter * arg1; // Dummy
+ TQPainter * arg1; // Dummy
bool arg2 = extractBool(exec, args, 2);
@@ -995,17 +995,17 @@ KJS::Value TQCanvasImp::drawCanvasArea_44( KJS::ExecState *exec, KJS::Object &ob
KJS::Value TQCanvasImp::drawViewArea_45( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasView *
return KJS::Value();
- TTQCanvasView * arg0; // Dummy
+ TQCanvasView * arg0; // Dummy
- // Unsupported parameter TTQPainter *
+ // Unsupported parameter TQPainter *
return KJS::Value();
- TTQPainter * arg1; // Dummy
+ TQPainter * arg1; // Dummy
- TTQRect arg2 = extractTQRect(exec, args, 2);
+ TQRect arg2 = extractTQRect(exec, args, 2);
bool arg3 = extractBool(exec, args, 3);
@@ -1021,10 +1021,10 @@ KJS::Value TQCanvasImp::drawViewArea_45( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasImp::addItem_46( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasItem *
return KJS::Value();
- TTQCanvasItem * arg0; // Dummy
+ TQCanvasItem * arg0; // Dummy
instance->addItem(
arg0 );
@@ -1035,10 +1035,10 @@ KJS::Value TQCanvasImp::addItem_46( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value TQCanvasImp::addAnimation_47( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasItem *
return KJS::Value();
- TTQCanvasItem * arg0; // Dummy
+ TQCanvasItem * arg0; // Dummy
instance->addAnimation(
arg0 );
@@ -1049,10 +1049,10 @@ KJS::Value TQCanvasImp::addAnimation_47( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasImp::removeItem_48( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasItem *
return KJS::Value();
- TTQCanvasItem * arg0; // Dummy
+ TQCanvasItem * arg0; // Dummy
instance->removeItem(
arg0 );
@@ -1063,10 +1063,10 @@ KJS::Value TQCanvasImp::removeItem_48( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasImp::removeAnimation_49( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter TTQCanvasItem *
return KJS::Value();
- TTQCanvasItem * arg0; // Dummy
+ TQCanvasItem * arg0; // Dummy
instance->removeAnimation(
arg0 );
@@ -797,10 +797,10 @@ KJS::Value TQCanvasImp::setUnchanged_32( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasImp::addItemToChunk_33( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasItem *
+ // Unsupported parameter TQCanvasItem *
return KJS::Value();
@@ -817,10 +817,10 @@ KJS::Value TQCanvasImp::addItemToChunk_33( KJS::ExecState *exec, KJS::Object &ob
KJS::Value TQCanvasImp::removeItemFromChunk_34( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasItem *
+ // Unsupported parameter TQCanvasItem *
return KJS::Value();
@@ -837,10 +837,10 @@ KJS::Value TQCanvasImp::removeItemFromChunk_34( KJS::ExecState *exec, KJS::Objec
KJS::Value TQCanvasImp::addItemToChunkContaining_35( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasItem *
+ // Unsupported parameter TQCanvasItem *
return KJS::Value();
@@ -857,10 +857,10 @@ KJS::Value TQCanvasImp::addItemToChunkContaining_35( KJS::ExecState *exec, KJS::
KJS::Value TQCanvasImp::removeItemFromChunkContaining_36( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasItem *
+ // Unsupported parameter TQCanvasItem *
return KJS::Value();
@@ -947,10 +947,10 @@ KJS::Value TQCanvasImp::drawArea_41( KJS::ExecState *exec, KJS::Object &obj, con
KJS::Value TQCanvasImp::addView_42( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasView *
+ // Unsupported parameter TQCanvasView *
return KJS::Value();
@@ -961,10 +961,10 @@ KJS::Value TQCanvasImp::addView_42( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value TQCanvasImp::removeView_43( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasView *
+ // Unsupported parameter TQCanvasView *
return KJS::Value();
@@ -995,17 +995,17 @@ KJS::Value TQCanvasImp::drawCanvasArea_44( KJS::ExecState *exec, KJS::Object &ob
KJS::Value TQCanvasImp::drawViewArea_45( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasView *
+ // Unsupported parameter TQCanvasView *
return KJS::Value();
@@ -1021,10 +1021,10 @@ KJS::Value TQCanvasImp::drawViewArea_45( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasImp::addItem_46( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasItem *
+ // Unsupported parameter TQCanvasItem *
return KJS::Value();
@@ -1035,10 +1035,10 @@ KJS::Value TQCanvasImp::addItem_46( KJS::ExecState *exec, KJS::Object &obj, cons
KJS::Value TQCanvasImp::addAnimation_47( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasItem *
+ // Unsupported parameter TQCanvasItem *
return KJS::Value();
@@ -1049,10 +1049,10 @@ KJS::Value TQCanvasImp::addAnimation_47( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasImp::removeItem_48( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasItem *
+ // Unsupported parameter TQCanvasItem *
return KJS::Value();
@@ -1063,10 +1063,10 @@ KJS::Value TQCanvasImp::removeItem_48( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasImp::removeAnimation_49( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter TTQCanvasItem *
+ // Unsupported parameter TQCanvasItem *
return KJS::Value();